@@ -5,9 +5,10 @@ from python_search.config import ConfigurationLoader, PythonSearchConfiguration
 from python_search.entry_runner import EntryRunner
 from python_search.environment import is_mac
 from python_search.events.run_performed import RunPerformed
-from python_search.events.run_performed.client import LogRunPerformedClient
+from python_search.events.run_performed.writer import LogRunPerformedClient
 from python_search.search_ui.fzf_kitty import FzfInKitty
 from python_search.search_ui.preview import Preview
+from python_search.exceptions import notify_exception
 
 
 class PythonSearchCli:
@@ -60,11 +61,13 @@ class PythonSearchCli:
         self.configuration = configuration
         self.run_key = EntryRunner(self.configuration).run
 
+    @notify_exception()
     def search(self):
         """
         Opens the Search UI. Main entrypoint of the application
         """
-        FzfInKitty.build_search_ui(self.configuration).run()
+        FzfInKitty(self.configuration).run()
+
 
     def edit_main(self):
         """Edit the main script"""
@@ -78,50 +81,60 @@ class PythonSearchCli:
 
         return RegisterNew(self.configuration)
 
-    def edit_key(self, key):
+    def edit_key(self, entry_str):
         from python_search.entry_capture.edit_content import EditKey
 
-        return EditKey(self.configuration).edit_key(key, dry_run=False)
 
-    def _copy_entry_content(self, key: str):
+        result =  EditKey(self.configuration).edit_key(entry_str, dry_run=False)
+        key = entry_str.split(":")[0]
+        LogRunPerformedClient().send(
+            RunPerformed(key=key, query_input="", shortcut=False)
+        )
+        return result
+
+    def _copy_entry_content(self, entry_str: str):
         """
         Copies the content of the provided key to the clipboard.
         Used by fzf to provide Ctrl-c functionality.
         """
-        from python_search.interpreter.interpreter_matcher import \
-            InterpreterMatcher
+        from python_search.interpreter.interpreter_matcher import InterpreterMatcher
 
+        key = entry_str.split(":")[0]
         InterpreterMatcher.build_instance(self.configuration).clipboard(key)
+        print(f"Key: {key}")
         LogRunPerformedClient().send(
             RunPerformed(key=key, query_input="", shortcut=False)
         )
 
-    def _copy_key_only(self, key_str: str):
+    def _copy_key_only(self, entry_str: str):
         """
         Copies to clipboard the key
         """
         from python_search.apps.clipboard import Clipboard
 
-        only_key = key_str.split(":")[0]
-        Clipboard().set_content(only_key)
+        key = entry_str.split(":")[0]
+        Clipboard().set_content(key)
         LogRunPerformedClient().send(
-            RunPerformed(key=only_key, query_input="", shortcut=False)
+            RunPerformed(key=key, query_input="", shortcut=False)
         )
 
-    def shortcut_generator(self):
+    def shortcut(self):
         """Generate shorcuts for all environments"""
         from python_search.shortcut.generator import ShortcutGenerator
 
         return ShortcutGenerator(self.configuration)
 
-    def _search_edit(self, key=None):
+    def _search_edit(self, entry_str=None):
         from python_search.entry_capture.edit_content import EditKey
 
-        result = EditKey(self.configuration).search_entries_directory(key)
+        result = EditKey(self.configuration).search_entries_directory(entry_str)
 
-        LogRunPerformedClient().send(
-            RunPerformed(key=key, query_input="", shortcut=False)
-        )
+
+        if entry_str.split(":"):
+            key = entry_str.split(":")[0]
+            LogRunPerformedClient().send(
+                RunPerformed(key=key, query_input="", shortcut=False)
+            )
         return result
 
     def _ranking(self):
@@ -169,8 +182,9 @@ class PythonSearchCli:
 
     def _entry_type_classifier(self):
 
-        from python_search.entry_type.classifier_inference import \
-            ClassifierInferenceClient
+        from python_search.entry_type.classifier_inference import (
+            ClassifierInferenceClient,
+        )
 
         class EntryTypeClassifierAPI:
             def __init__(self):
