@@ -25,6 +25,7 @@ class DataConfig:
 
     # output of the _model
     base_data_folder = f"{os.environ['HOME']}/.data/data/python_search"
+    BASE_DATA_COLLECTOR_FOLDER = f"{os.environ['HOME']}/.data/data_collection"
     prediction_batch_location = base_data_folder + "/predict_input_lenght/latest"
     # a copy of the search run _entries for the feature store
     entries_dump = base_data_folder + "/entries_dumped/latest"
@@ -51,7 +52,7 @@ class KafkaConfig:
 
 
 class RedisConfig:
-    host =  "127.0.0.1" if is_mac() else "host.docker.internal"
+    host = "127.0.0.1" if is_mac() else "host.docker.internal"
     port = 6379
 
 
@@ -61,7 +62,7 @@ class PythonSearchConfiguration(EntriesGroup):
     Everything to customize about the application is configurable via code through this class
     """
 
-    APPLICATION_TITLE = "SearchPythonSearch"
+    APPLICATION_TITLE = "PythonSearchWindow"
     commands: dict
     simple_gui_theme = "SystemDefault1"
     simple_gui_font_size = 14
@@ -100,6 +101,9 @@ class PythonSearchConfiguration(EntriesGroup):
 
         self._initialization_time = datetime.now()
 
+    def get_default_tags(self):
+        return self._default_tags
+
 
 class ConfigurationLoader:
     """
@@ -119,9 +123,7 @@ class ConfigurationLoader:
         if folder not in sys.path:
             sys.path.insert(0, folder)
         import copy
-
         from entries_main import config
-
         return copy.deepcopy(config)
 
     def reload(self):
@@ -165,5 +167,4 @@ class ConfigurationLoader:
         return folder
 
     def load_entries(self):
-        config = self.load_config()
-        return config.commands
+        return self.load_config().commands
