@@ -4,13 +4,16 @@ import datetime
 import time
 
 from python_search.apps.clipboard import Clipboard
-from python_search.entry_capture.filesystem_entry_inserter import FilesystemEntryInserter
-from python_search.entry_capture.entry_inserter_gui import (EntryCaptureGUI,
-                                                            GuiEntryData)
+from python_search.config import ConfigurationLoader
+from python_search.entry_capture.filesystem_entry_inserter import (
+    FilesystemEntryInserter,
+)
+from python_search.entry_capture.entry_inserter_gui import EntryCaptureGUI, GuiEntryData
 from python_search.entry_type.entity import infer_default_type
 from python_search.exceptions import RegisterNewException
 from python_search.interpreter.base import BaseInterpreter
 from python_search.interpreter.interpreter_matcher import InterpreterMatcher
+from python_search.exceptions import notify_exception
 
 
 class RegisterNew:
@@ -18,10 +21,15 @@ class RegisterNew:
     Entry point for the registering of new entries
     """
 
-    def __init__(self, configuration):
+    def __init__(self, configuration=None):
+
+        if not configuration:
+            configuration = ConfigurationLoader().load_config()
+
         self.configuration = configuration
         self.entry_inserter = FilesystemEntryInserter(configuration)
 
+    @notify_exception()
     def register(self, *, key: str, value: str, tag: str = None):
         """
         The non ui driven registering api
@@ -33,7 +41,7 @@ class RegisterNew:
         Returns:
 
         """
-
+        print(f"Registering new entry with tag = {tag}")
         key = self._sanitize_key(key)
 
         interpreter: BaseInterpreter = InterpreterMatcher.build_instance(
@@ -48,6 +56,7 @@ class RegisterNew:
     def _sanitize_key(self, key):
         return key.replace("\n", " ").replace(":", " ")
 
+    @notify_exception()
     def launch_ui(self, default_type=None, default_key=None, default_content=None):
         """
         Create a new inferred entry based on the clipboard content
@@ -77,7 +86,6 @@ class RegisterNew:
 
         self.entry_inserter.insert(key, dict_entry)
 
-
     def anonymous_snippet(self):
         """
         Create an anonymous snippet entry
