@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import json
 import re
 from typing import List
 
@@ -8,10 +7,12 @@ from python_search.apps.notification_ui import send_notification
 from python_search.config import PythonSearchConfiguration
 from python_search.context import Context
 from python_search.events.run_performed import RunPerformed
-from python_search.events.run_performed.client import LogRunPerformedClient
+from python_search.events.run_performed.writer import LogRunPerformedClient
 from python_search.interpreter.cmd import CmdInterpreter
 from python_search.interpreter.interpreter_matcher import InterpreterMatcher
-from python_search.logger import setup_run_key_logger
+from python_search.logger import setup_run_key_logger, StreamToLogger
+from python_search.exceptions import notify_exception
+from python_search.search_ui.serialized_entry import decode_serialized_data_from_entry_text
 
 logger = setup_run_key_logger()
 
@@ -24,9 +25,10 @@ class EntryRunner:
     def __init__(self, configuration: PythonSearchConfiguration):
         self.configuration = configuration
 
+    @notify_exception()
     def run(
         self,
-        key: str,
+        entry_text: str,
         query_used: str = "",
         force_gui_mode=False,
         gui_mode=False,
@@ -40,26 +42,20 @@ class EntryRunner:
             entry_rank_position: accounts for where the entry was when it was executed, if passed it will be used for
             from_shortcut means that the key execution was triggered by a desktop shortcut
         """
+        key = entry_text.split(":")[0] if ':' in entry_text else entry_text
 
         logger.info("Arrived at run key")
         # if there are : in the line just take all before it as it is
         # usually the key from fzf, and our keys do not accept :
-        metadata = ""
-        if ":" in key:
-            key, metadata = key.split(":", 1)
-            logger.info(f"metadata: {metadata}")
 
         if from_shortcut:
             send_notification(f"{key}")
 
-        rank_position = None
 
-        if metadata:
-            try:
-                matadata_dict = json.loads(metadata)
-                rank_position = matadata_dict.get("position")
-            except BaseException as e:
-                logger.warning(f"Could not decode metadata: {e}")
+        metadata = decode_serialized_data_from_entry_text(entry_text, logger)
+        logger.info(f"Decoded metadata {metadata}")
+        rank_position = metadata.get("position")
+
 
         # when there are no matches we actually will use the query and interpret it
         if not key and query_used:
@@ -93,9 +89,16 @@ class EntryRunner:
 
         result = InterpreterMatcher.build_instance(self.configuration).default(real_key)
 
-        LogRunPerformedClient().send(
-            RunPerformed(key=key, query_input=query_used, shortcut=from_shortcut)
+        logger.info("Passed interpreter")
+        run_performed = RunPerformed(
+            key=key,
+            query_input=query_used,
+            shortcut=from_shortcut,
+            rank_uuid=metadata.get("uuid"),
+            rank_position=metadata.get("position")
         )
+        logger.info(f"Run performed = {run_performed}")
+        LogRunPerformedClient().send(run_performed)
         return result
 
     def _matching_keys(self, key: str) -> List[str]:
