@@ -1,11 +1,11 @@
-import json
-import logging
 from datetime import datetime
 
 from colorama import Fore
 from dateutil import parser
 
 from python_search.config import ConfigurationLoader
+from python_search.logger import setup_preview_logger
+from python_search.search_ui.serialized_entry import decode_serialized_data_from_entry_text
 
 
 class Preview:
@@ -15,9 +15,8 @@ class Preview:
 
     def __init__(self):
         self.configuration = ConfigurationLoader()
-        self.logger = logging.getLogger("preview_entry")
+        self.logger = setup_preview_logger()
         # do not send the errors to stderr, in the future we should send to kibana or a file
-        self.logger.disabled = True
 
     def display(self, entry_text: str):
         """
@@ -48,6 +47,9 @@ class Preview:
         if "position" in data:
             print("Position: " + data["position"])
 
+        if "uuid" in data:
+            print("Uuid: " + data["uuid"][0:8])
+
     def _get_color_for_type(self, type):
         if type == "Cmd":
             return Fore.RED
@@ -58,10 +60,8 @@ class Preview:
         return Fore.BLUE
 
     def _build_values_to_print(self, entry_text) -> dict:
-        print_values = entry_text.split(":")
-        key = print_values[0]
+        key = entry_text.split(":")[0]
         # the entry content is after the key + a ":" character
-        serialized_content = entry_text[len(key) + 1 :]
 
         result = {}
         result["type"] = "Unknown"
@@ -99,7 +99,7 @@ class Preview:
         if "description" in entry_data:
             result["description"] = entry_data["description"]
 
-        decoded_content = self._decode_serialized_data(serialized_content)
+        decoded_content = decode_serialized_data_from_entry_text(entry_text, self.logger)
 
         if "position" in decoded_content:
             result["position"] = str(decoded_content["position"])
@@ -111,17 +111,14 @@ class Preview:
         if "tags" in decoded_content:
             result["tags"] = " ".join(decoded_content["tags"])
 
+        if "uuid" in decoded_content:
+            result["uuid"] = str(decoded_content["uuid"])
+
         return result
 
     def _color_str(self, a_string, a_color) -> str:
         return f"{a_color}{a_string}{Fore.RESET}"
 
-    def _decode_serialized_data(self, serialized_content):
-        try:
-            return json.loads(serialized_content)
-        except Exception as e:
-            self.logger.error(str(e))
-            return []
 
     def _load_key_data(self, key):
         entries = self.configuration.load_entries()
