@@ -1,10 +1,14 @@
 from fastapi import FastAPI
 from fastapi.responses import PlainTextResponse
 
-from python_search.entry_type.classifier_inference import (EntryData,
-                                                           PredictEntryTypeInference)
+from python_search.entry_description_generator.description_geneartor import DescriptionGenerator, EntryKeyGeneratorCmd
+from python_search.entry_type.classifier_inference import (
+    EntryData,
+    PredictEntryTypeInference,
+)
 from python_search.events.latest_used_entries import RecentKeys
-from python_search.events.run_performed import RunPerformed, RunPerformedWriter
+from python_search.events.run_performed import RunPerformed
+from python_search.events.run_performed.writer import RunPerformedWriter
 from python_search.config import ConfigurationLoader
 from python_search.search.search import Search
 
@@ -15,6 +19,7 @@ app = FastAPI()
 generator = Search(ConfigurationLoader().load_config())
 ranking_result = generator.search()
 entry_type_inference = PredictEntryTypeInference()
+description_generator = DescriptionGenerator()
 
 
 def reload_ranking():
@@ -63,23 +68,29 @@ def health():
 def log_run(event: RunPerformed):
 
     RecentKeys.add_latest_used(event.key)
-
     RunPerformedWriter().write(event)
-
     # regenerate the search after running a key
     reload()
 
     return event
 
+
 @app.post("/entry_type/classify")
 def predict_entry_type_endpoint(entry: EntryData):
     type, uuid = entry_type_inference.predict_entry_type(entry)
     return {"predicted_type": type, "prediction_uuid": uuid}
 
 
+@app.post("/entry/generate_description")
+def generate_description(entry: EntryKeyGeneratorCmd):
+    result = description_generator.generate(entry)
+    return {"generated_description": result}
+
+
 @app.get("/recent_history")
 def recent_history_endpoint():
-    return RecentKeys().get_latest_used_keys()
+    return {"history": RecentKeys().get_latest_used_keys()}
+
 
 
 def main():
